==> aws-cdk.aws-eks-1.72.0.tar.gz: package/lib/k8s-object-value.d.ts <==
import { Duration } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { ICluster } from './cluster';
import { Construct as CoreConstruct } from '@aws-cdk/core';
/**
 * (experimental) Properties for KubernetesObjectValue.
 *
 * @experimental
 */
export interface KubernetesObjectValueProps {
    /**
     * (experimental) The EKS cluster to fetch attributes from.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @experimental
     */
    readonly cluster: ICluster;
    /**
     * (experimental) The object type to query.
     *
     * (e.g 'service', 'pod'...)
     *
     * @experimental
     */
    readonly objectType: string;
    /**
     * (experimental) The name of the object to query.
     *
     * @experimental
     */
    readonly objectName: string;
    /**
     * (experimental) The namespace the object belongs to.
     *
     * @default 'default'
     * @experimental
     */
    readonly objectNamespace?: string;
    /**
     * (experimental) JSONPath to the specific value.
     *
     * @see https://kubernetes.io/docs/reference/kubectl/jsonpath/
     * @experimental
     */
    readonly jsonPath: string;
    /**
     * (experimental) Timeout for waiting on a value.
     *
     * @default Duration.minutes(5)
     * @experimental
     */
    readonly timeout?: Duration;
}
/**
 * (experimental) Represents a value of a specific object deployed in the cluster.
 *
 * Use this to fetch any information available by the `kubectl get` command.
 *
 * @experimental
 */
export declare class KubernetesObjectValue extends CoreConstruct {
    /**
     * (experimental) The CloudFormation reosurce type.
     *
     * @experimental
     */
    static readonly RESOURCE_TYPE = "Custom::AWSCDK-EKS-KubernetesObjectValue";
    private _resource;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: KubernetesObjectValueProps);
    /**
     * (experimental) The value as a string token.
     *
     * @experimental
     */
    get value(): string;
}

==> aws-cdk.aws-eks-1.123.0.tar.gz: package/lib/k8s-object-value.d.ts <==
import { Duration } from '@aws-cdk/core';
import { Construct } from 'constructs';
import { ICluster } from './cluster';
import { Construct as CoreConstruct } from '@aws-cdk/core';
/**
 * Properties for KubernetesObjectValue.
 *
 * @stability stable
 */
export interface KubernetesObjectValueProps {
    /**
     * The EKS cluster to fetch attributes from.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @stability stable
     */
    readonly cluster: ICluster;
    /**
     * The object type to query.
     *
     * (e.g 'service', 'pod'...)
     *
     * @stability stable
     */
    readonly objectType: string;
    /**
     * The name of the object to query.
     *
     * @stability stable
     */
    readonly objectName: string;
    /**
     * The namespace the object belongs to.
     *
     * @default 'default'
     * @stability stable
     */
    readonly objectNamespace?: string;
    /**
     * JSONPath to the specific value.
     *
     * @see https://kubernetes.io/docs/reference/kubectl/jsonpath/
     * @stability stable
     */
    readonly jsonPath: string;
    /**
     * Timeout for waiting on a value.
     *
     * @default Duration.minutes(5)
     * @stability stable
     */
    readonly timeout?: Duration;
}
/**
 * Represents a value of a specific object deployed in the cluster.
 *
 * Use this to fetch any information available by the `kubectl get` command.
 *
 * @stability stable
 */
export declare class KubernetesObjectValue extends CoreConstruct {
    /**
     * The CloudFormation reosurce type.
     *
     * @stability stable
     */
    static readonly RESOURCE_TYPE = "Custom::AWSCDK-EKS-KubernetesObjectValue";
    private _resource;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: KubernetesObjectValueProps);
    /**
     * The value as a string token.
     *
     * @stability stable
     */
    get value(): string;
}
